Package: CurricularComplexity
Type: Package
Title: Toolkit for Analyzing Curricular Complexity
Version: 1.1.0
Authors@R: c(person(given = "David", family = "Reeping", role = c("aut","cre"), email = "reepindp@ucmail.uc.edu"))
Author: David Reeping [aut, cre]
Maintainer: David Reeping <reepindp@ucmail.uc.edu>
Description: Enables educational researchers and practitioners to calculate the curricular complexity of a plan of study, visualize its prerequisite structure at scale, and conduct customizable analyses. The original tool can be found at <https://curricularanalytics.org>. Additional functions to explore curriculum complexity from the literature are also included.
Depends: R (>= 3.6.2), igraph (>= 1.2.5)
Encoding: UTF-8
License: MIT + file LICENSE
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-08-20 18:56:45 UTC; reepi
Repository: CRAN
Date/Publication: 2026-08-21 05:46:55 UTC
