% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/topic_cruciality.R
\name{topic_cruciality}
\alias{topic_cruciality}
\title{Calculate Topic Cruciality}
\usage{
topic_cruciality(plan_of_study, course_code_stem, include_coreqs = TRUE)
}
\arguments{
\item{plan_of_study}{A plan of study for which course crucialities can be
calculated.}

\item{course_code_stem}{A character string identifying the course-code stem
used to define the topic area. For example, `"MATH"` identifies all
mathematics courses with the `"MATH"` course-code stem.}

\item{include_coreqs}{A logical value indicating whether corequisite
relationships should be included when calculating course crucialities.
Defaults to TRUE.}
}
\value{
The topic cruciality, calculated as the sum of the cruciality values
  for courses in the plan of study with the specified course-code stem.
}
\description{
Calculates the cruciality attributable to a particular course-code stem
within a plan of study. Topic cruciality is calculated as the sum of the
cruciality values for all courses in the plan of study whose course code
matches the specified course-code stem.
}
\details{
This measure is generalized from the concept of math cruciality described
by Ryan (2026), which examines the contribution of required mathematics
courses to curriculum complexity. Rather than being restricted to
mathematics, this function can be used to calculate the cruciality of any
collection of courses that can be identified by a common course-code stem.
}
\references{
Ryan, O. J. (2026). *The Role of Math Courses in Engineering Education:
Examining How Math Courses Shape First-Year Student Transition, Curriculum
Complexity, and Time-to-Degree* (Doctoral dissertation, Virginia Tech).
https://vtechworks.lib.vt.edu/items/4ddd7b33-8700-45d4-988d-2111a2970389
}
